@@ -9,11 +9,13 @@
 #ifndef AKONADI_DIALPHONENUMBERACTION_H
 #define AKONADI_DIALPHONENUMBERACTION_H
 
-namespace KContacts {
+namespace KContacts
+{
 class PhoneNumber;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
  * @short An action to dial the phone number of a contact.
  *
