@@ -12,17 +12,17 @@
 #include "contactgroupeditordialog.h"
 
 #include <entitytreemodel.h>
-#include <mimetypechecker.h>
 #include <kcontacts/addressee.h>
 #include <kcontacts/contactgroup.h>
+#include <mimetypechecker.h>
 
-#include <QAction>
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QAction>
 
-#include <QPointer>
 #include <QItemSelectionModel>
+#include <QPointer>
 
 using namespace Akonadi;
 
@@ -35,11 +35,9 @@ public:
         , mParent(parent)
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
-        mParent->connect(mGenericManager, &StandardActionManager::actionStateUpdated,
-                         mParent, &StandardContactActionManager::actionStateUpdated);
+        mParent->connect(mGenericManager, &StandardActionManager::actionStateUpdated, mParent, &StandardContactActionManager::actionStateUpdated);
 
-        mGenericManager->setMimeTypeFilter(
-            QStringList() << KContacts::Addressee::mimeType() << KContacts::ContactGroup::mimeType());
+        mGenericManager->setMimeTypeFilter(QStringList() << KContacts::Addressee::mimeType() << KContacts::ContactGroup::mimeType());
 
         mGenericManager->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
     }
@@ -94,177 +92,147 @@ public:
     {
         switch (type) {
         case Akonadi::StandardActionManager::CreateCollection:
-            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setText(
-                i18n("Add Address Book Folder..."));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setText(i18n("Add Address Book Folder..."));
 
-            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setWhatsThis(
-                i18n("Add a new address book folder to the currently selected address book folder."));
-            mGenericManager->setContextText(
-                StandardActionManager::CreateCollection, StandardActionManager::DialogTitle,
-                i18nc("@title:window", "New Address Book Folder"));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)
+                ->setWhatsThis(i18n("Add a new address book folder to the currently selected address book folder."));
+            mGenericManager->setContextText(StandardActionManager::CreateCollection,
+                                            StandardActionManager::DialogTitle,
+                                            i18nc("@title:window", "New Address Book Folder"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText,
-                ki18n("Could not create address book folder: %1"));
+            mGenericManager->setContextText(StandardActionManager::CreateCollection,
+                                            StandardActionManager::ErrorMessageText,
+                                            ki18n("Could not create address book folder: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageTitle,
-                i18n("Address book folder creation failed"));
-            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setProperty("ContentMimeTypes", QStringList()
-                                                                                                   <<QStringLiteral("application/x-vnd.kde.contactgroup")
-                                                                                                   <<QStringLiteral("text/directory")
-                                                                                                   <<QStringLiteral("application/x-vnd.kde.contactgroup"));
+            mGenericManager->setContextText(StandardActionManager::CreateCollection,
+                                            StandardActionManager::ErrorMessageTitle,
+                                            i18n("Address book folder creation failed"));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)
+                ->setProperty("ContentMimeTypes",
+                              QStringList() << QStringLiteral("application/x-vnd.kde.contactgroup") << QStringLiteral("text/directory")
+                                            << QStringLiteral("application/x-vnd.kde.contactgroup"));
 
             break;
         case Akonadi::StandardActionManager::CopyCollections:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyCollections,
-                                           ki18np("Copy Address Book Folder",
-                                                  "Copy %1 Address Book Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::CopyCollections)->setWhatsThis(
-                i18n("Copy the selected address book folders to the clipboard."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyCollections, ki18np("Copy Address Book Folder", "Copy %1 Address Book Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::CopyCollections)
+                ->setWhatsThis(i18n("Copy the selected address book folders to the clipboard."));
             break;
         case Akonadi::StandardActionManager::DeleteCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteCollections,
-                                           ki18np("Delete Address Book Folder",
-                                                  "Delete %1 Address Book Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::DeleteCollections)->setWhatsThis(
-                i18n("Delete the selected address book folders from the address book."));
+                                           ki18np("Delete Address Book Folder", "Delete %1 Address Book Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::DeleteCollections)
+                ->setWhatsThis(i18n("Delete the selected address book folders from the address book."));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::MessageBoxText,
-                ki18np("Do you really want to delete this address book folder and all its sub-folders?",
-                       "Do you really want to delete %1 address book folders and all their sub-folders?"));
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::MessageBoxTitle,
-                ki18ncp("@title:window", "Delete address book folder?", "Delete address book folders?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::MessageBoxText,
+                                            ki18np("Do you really want to delete this address book folder and all its sub-folders?",
+                                                   "Do you really want to delete %1 address book folders and all their sub-folders?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::MessageBoxTitle,
+                                            ki18ncp("@title:window", "Delete address book folder?", "Delete address book folders?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageText,
-                ki18n("Could not delete address book folder: %1"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::ErrorMessageText,
+                                            ki18n("Could not delete address book folder: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageTitle,
-                i18n("Address book folder deletion failed"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::ErrorMessageTitle,
+                                            i18n("Address book folder deletion failed"));
             break;
         case Akonadi::StandardActionManager::SynchronizeCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeCollections,
-                                           ki18np("Update Address Book Folder",
-                                                  "Update %1 Address Book Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollections)->setWhatsThis(
-                i18n("Update the content of the selected address book folders."));
+                                           ki18np("Update Address Book Folder", "Update %1 Address Book Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollections)
+                ->setWhatsThis(i18n("Update the content of the selected address book folders."));
             break;
         case Akonadi::StandardActionManager::CutCollections:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CutCollections,
-                                           ki18np("Cut Address Book Folder",
-                                                  "Cut %1 Address Book Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::CutCollections)->setWhatsThis(
-                i18n("Cut the selected address book folders from the address book."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CutCollections, ki18np("Cut Address Book Folder", "Cut %1 Address Book Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::CutCollections)
+                ->setWhatsThis(i18n("Cut the selected address book folders from the address book."));
             break;
         case Akonadi::StandardActionManager::CollectionProperties:
-            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)->setText(
-                i18n("Folder Properties..."));
-            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)->setWhatsThis(
-                i18n("Open a dialog to edit the properties of the selected address book folder."));
-            mGenericManager->setContextText(
-                StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,
-                ki18nc("@title:window", "Properties of Address Book Folder %1"));
+            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)->setText(i18n("Folder Properties..."));
+            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)
+                ->setWhatsThis(i18n("Open a dialog to edit the properties of the selected address book folder."));
+            mGenericManager->setContextText(StandardActionManager::CollectionProperties,
+                                            StandardActionManager::DialogTitle,
+                                            ki18nc("@title:window", "Properties of Address Book Folder %1"));
             break;
         case Akonadi::StandardActionManager::CopyItems:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                           ki18np("Copy Contact", "Copy %1 Contacts"));
-            mGenericManager->action(Akonadi::StandardActionManager::CopyItems)->setWhatsThis(
-                i18n("Copy the selected contacts to the clipboard."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy Contact", "Copy %1 Contacts"));
+            mGenericManager->action(Akonadi::StandardActionManager::CopyItems)->setWhatsThis(i18n("Copy the selected contacts to the clipboard."));
             break;
         case Akonadi::StandardActionManager::DeleteItems:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                           ki18np("Delete Contact", "Delete %1 Contacts"));
-            mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)->setWhatsThis(
-                i18n("Delete the selected contacts from the address book."));
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::MessageBoxText,
-                ki18np("Do you really want to delete the selected contact?",
-                       "Do you really want to delete %1 contacts?"));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete Contact", "Delete %1 Contacts"));
+            mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)->setWhatsThis(i18n("Delete the selected contacts from the address book."));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems,
+                                            StandardActionManager::MessageBoxText,
+                                            ki18np("Do you really want to delete the selected contact?", "Do you really want to delete %1 contacts?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::MessageBoxTitle,
-                ki18ncp("@title:window", "Delete Contact?", "Delete Contacts?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems,
+                                            StandardActionManager::MessageBoxTitle,
+                                            ki18ncp("@title:window", "Delete Contact?", "Delete Contacts?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText,
-                ki18n("Could not delete contact: %1"));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText, ki18n("Could not delete contact: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle,
-                i18n("Contact deletion failed"));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle, i18n("Contact deletion failed"));
             break;
         case Akonadi::StandardActionManager::CutItems:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                           ki18np("Cut Contact", "Cut %1 Contacts"));
-            mGenericManager->action(Akonadi::StandardActionManager::CutItems)->setWhatsThis(
-                i18n("Cut the selected contacts from the address book."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut Contact", "Cut %1 Contacts"));
+            mGenericManager->action(Akonadi::StandardActionManager::CutItems)->setWhatsThis(i18n("Cut the selected contacts from the address book."));
             break;
         case Akonadi::StandardActionManager::CreateResource:
-            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)->setText(
-                i18n("Add &Address Book..."));
-            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)->setWhatsThis(
-                i18n("Add a new address book<p>"
-                     "You will be presented with a dialog where you can select "
-                     "the type of the address book that shall be added.</p>"));
-            mGenericManager->setContextText(
-                StandardActionManager::CreateResource, StandardActionManager::DialogTitle,
-                i18nc("@title:window", "Add Address Book"));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)->setText(i18n("Add &Address Book..."));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)
+                ->setWhatsThis(i18n("Add a new address book<p>"
+                                    "You will be presented with a dialog where you can select "
+                                    "the type of the address book that shall be added.</p>"));
+            mGenericManager->setContextText(StandardActionManager::CreateResource,
+                                            StandardActionManager::DialogTitle,
+                                            i18nc("@title:window", "Add Address Book"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateResource, StandardActionManager::ErrorMessageText,
-                ki18n("Could not create address book: %1"));
+            mGenericManager->setContextText(StandardActionManager::CreateResource,
+                                            StandardActionManager::ErrorMessageText,
+                                            ki18n("Could not create address book: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateResource, StandardActionManager::ErrorMessageTitle,
-                i18n("Address book creation failed"));
+            mGenericManager->setContextText(StandardActionManager::CreateResource,
+                                            StandardActionManager::ErrorMessageTitle,
+                                            i18n("Address book creation failed"));
             break;
         case Akonadi::StandardActionManager::DeleteResources:
 
-            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteResources,
-                                           ki18np("&Delete Address Book",
-                                                  "&Delete %1 Address Books"));
-            mGenericManager->action(Akonadi::StandardActionManager::DeleteResources)->setWhatsThis(
-                i18n("Delete the selected address books<p>"
-                     "The currently selected address books will be deleted, "
-                     "along with all the contacts and contact groups they contain.</p>"));
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteResources, StandardActionManager::MessageBoxText,
-                ki18np("Do you really want to delete this address book?",
-                       "Do you really want to delete %1 address books?"));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteResources, ki18np("&Delete Address Book", "&Delete %1 Address Books"));
+            mGenericManager->action(Akonadi::StandardActionManager::DeleteResources)
+                ->setWhatsThis(i18n("Delete the selected address books<p>"
+                                    "The currently selected address books will be deleted, "
+                                    "along with all the contacts and contact groups they contain.</p>"));
+            mGenericManager->setContextText(StandardActionManager::DeleteResources,
+                                            StandardActionManager::MessageBoxText,
+                                            ki18np("Do you really want to delete this address book?", "Do you really want to delete %1 address books?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteResources, StandardActionManager::MessageBoxTitle,
-                ki18ncp("@title:window", "Delete Address Book?", "Delete Address Books?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteResources,
+                                            StandardActionManager::MessageBoxTitle,
+                                            ki18ncp("@title:window", "Delete Address Book?", "Delete Address Books?"));
 
             break;
         case Akonadi::StandardActionManager::ResourceProperties:
 
-            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)->setText(
-                i18n("Address Book Properties..."));
-            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)->setWhatsThis(
-                i18n("Open a dialog to edit properties of the selected address book."));
+            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)->setText(i18n("Address Book Properties..."));
+            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)
+                ->setWhatsThis(i18n("Open a dialog to edit properties of the selected address book."));
             break;
         case Akonadi::StandardActionManager::SynchronizeResources:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeResources,
-                                           ki18np("Update Address Book",
-                                                  "Update %1 Address Books"));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeResources, ki18np("Update Address Book", "Update %1 Address Books"));
 
-            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeResources)->setWhatsThis
-                (i18n("Updates the content of all folders of the selected address books."));
+            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeResources)
+                ->setWhatsThis(i18n("Updates the content of all folders of the selected address books."));
 
             break;
         case StandardActionManager::Paste:
-            mGenericManager->setContextText(
-                StandardActionManager::Paste, StandardActionManager::ErrorMessageText,
-                ki18n("Could not paste contact: %1"));
+            mGenericManager->setContextText(StandardActionManager::Paste, StandardActionManager::ErrorMessageText, ki18n("Could not paste contact: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle,
-                i18n("Paste failed"));
+            mGenericManager->setContextText(StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle, i18n("Paste failed"));
             break;
         default:
             break;
@@ -273,11 +241,9 @@ public:
 
     static bool hasWritableCollection(const QModelIndex &index, const QString &mimeType)
     {
-        const Akonadi::Collection collection
-            = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         if (collection.isValid()) {
-            if (collection.contentMimeTypes().contains(mimeType)
-                && (collection.rights() & Akonadi::Collection::CanCreateItem)) {
+            if (collection.contentMimeTypes().contains(mimeType) && (collection.rights() & Akonadi::Collection::CanCreateItem)) {
                 return true;
             }
         }
@@ -323,8 +289,7 @@ public:
                     const QString mimeType = index.data(EntityTreeModel::MimeTypeRole).toString();
                     if (mimeType == KContacts::Addressee::mimeType()) {
                         if (mGenericManager->action(Akonadi::StandardActionManager::CopyItems)) {
-                            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                                           ki18np("Copy Contact", "Copy %1 Contacts"));
+                            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy Contact", "Copy %1 Contacts"));
                         }
                         QAction *act = mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu);
                         if (act) {
@@ -335,12 +300,10 @@ public:
                             act->setText(i18n("Copy Contact To"));
                         }
                         if (mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)) {
-                            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                                           ki18np("Delete Contact", "Delete %1 Contacts"));
+                            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete Contact", "Delete %1 Contacts"));
                         }
                         if (mGenericManager->action(Akonadi::StandardActionManager::CutItems)) {
-                            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                                           ki18np("Cut Contact", "Cut %1 Contacts"));
+                            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut Contact", "Cut %1 Contacts"));
                         }
                         act = mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu);
                         if (act) {
@@ -356,8 +319,7 @@ public:
                         }
                     } else if (mimeType == KContacts::ContactGroup::mimeType()) {
                         if (mGenericManager->action(Akonadi::StandardActionManager::CopyItems)) {
-                            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                                           ki18np("Copy Group", "Copy %1 Groups"));
+                            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy Group", "Copy %1 Groups"));
                         }
                         QAction *act = mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu);
                         if (act) {
@@ -368,12 +330,10 @@ public:
                             act->setText(i18n("Copy Group To"));
                         }
                         if (mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)) {
-                            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                                           ki18np("Delete Group", "Delete %1 Groups"));
+                            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete Group", "Delete %1 Groups"));
                         }
                         if (mGenericManager->action(Akonadi::StandardActionManager::CutItems)) {
-                            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                                           ki18np("Cut Group", "Cut %1 Groups"));
+                            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut Group", "Cut %1 Groups"));
                         }
                         act = mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu);
                         if (act) {
@@ -445,8 +405,7 @@ public:
             return;
         }
 
-        QPointer<Akonadi::ContactEditorDialog> dlg = new Akonadi::ContactEditorDialog(
-            Akonadi::ContactEditorDialog::CreateMode, mParentWidget);
+        QPointer<Akonadi::ContactEditorDialog> dlg = new Akonadi::ContactEditorDialog(Akonadi::ContactEditorDialog::CreateMode, mParentWidget);
         dlg->setDefaultAddressBook(selectedCollection());
         dlg->exec();
         delete dlg;
@@ -458,8 +417,7 @@ public:
             return;
         }
 
-        QPointer<Akonadi::ContactGroupEditorDialog> dlg = new Akonadi::ContactGroupEditorDialog(
-            Akonadi::ContactGroupEditorDialog::CreateMode, mParentWidget);
+        QPointer<Akonadi::ContactGroupEditorDialog> dlg = new Akonadi::ContactGroupEditorDialog(Akonadi::ContactGroupEditorDialog::CreateMode, mParentWidget);
         dlg->setDefaultAddressBook(selectedCollection());
         dlg->exec();
         delete dlg;
@@ -490,18 +448,15 @@ public:
         }
 
         if (Akonadi::MimeTypeChecker::isWantedItem(item, KContacts::Addressee::mimeType())) {
-            QPointer<Akonadi::ContactEditorDialog> dlg = new Akonadi::ContactEditorDialog(
-                Akonadi::ContactEditorDialog::EditMode, mParentWidget);
-            connect(dlg.data(), &ContactEditorDialog::error,
-                    mParent, [this](const QString &error) {
+            QPointer<Akonadi::ContactEditorDialog> dlg = new Akonadi::ContactEditorDialog(Akonadi::ContactEditorDialog::EditMode, mParentWidget);
+            connect(dlg.data(), &ContactEditorDialog::error, mParent, [this](const QString &error) {
                 slotContactEditorError(error);
             });
             dlg->setContact(item);
             dlg->exec();
             delete dlg;
         } else if (Akonadi::MimeTypeChecker::isWantedItem(item, KContacts::ContactGroup::mimeType())) {
-            QPointer<Akonadi::ContactGroupEditorDialog> dlg = new Akonadi::ContactGroupEditorDialog(
-                Akonadi::ContactGroupEditorDialog::EditMode, mParentWidget);
+            QPointer<Akonadi::ContactGroupEditorDialog> dlg = new Akonadi::ContactGroupEditorDialog(Akonadi::ContactGroupEditorDialog::EditMode, mParentWidget);
             dlg->setContactGroup(item);
             dlg->exec();
             delete dlg;
@@ -576,10 +531,11 @@ QAction *StandardContactActionManager::createAction(Type type)
         action = new QAction(d->mParentWidget);
         action->setIcon(QIcon::fromTheme(QStringLiteral("contact-new")));
         action->setText(i18n("New &Contact..."));
-        action->setWhatsThis(i18n("Create a new contact<p>You will be presented with a dialog where you can add data about a person, including addresses and phone numbers.</p>"));
+        action->setWhatsThis(i18n(
+            "Create a new contact<p>You will be presented with a dialog where you can add data about a person, including addresses and phone numbers.</p>"));
         d->mActions.insert(CreateContact, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_contact_create"), action);
-        d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_N));
+        d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_N));
         connect(action, &QAction::triggered, this, [this]() {
             d->slotCreateContact();
         });
@@ -591,7 +547,7 @@ QAction *StandardContactActionManager::createAction(Type type)
         action->setWhatsThis(i18n("Create a new group<p>You will be presented with a dialog where you can add a new group of contacts.</p>"));
         d->mActions.insert(CreateContactGroup, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_contact_group_create"), action);
-        d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_G));
+        d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_G));
         connect(action, &QAction::triggered, this, [this]() {
             d->slotCreateContactGroup();
         });
@@ -600,7 +556,9 @@ QAction *StandardContactActionManager::createAction(Type type)
         action = new QAction(d->mParentWidget);
         action->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
         action->setText(i18n("Edit Contact..."));
-        action->setWhatsThis(i18n("Edit the selected contact<p>You will be presented with a dialog where you can edit the data stored about a person, including addresses and phone numbers.</p>"));
+        action->setWhatsThis(
+            i18n("Edit the selected contact<p>You will be presented with a dialog where you can edit the data stored about a person, including addresses and "
+                 "phone numbers.</p>"));
         action->setEnabled(false);
         d->mActions.insert(EditItem, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_contact_item_edit"), action);
@@ -610,7 +568,7 @@ QAction *StandardContactActionManager::createAction(Type type)
         });
         break;
     default:
-        Q_ASSERT(false);   // should never happen
+        Q_ASSERT(false); // should never happen
         break;
     }
 
