@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,7 +12,8 @@
 #include "contacteditor_export.h"
 #include <QVariant>
 
-namespace ContactEditor {
+namespace ContactEditor
+{
 /**
  * @short A helper class for storing contact specific settings.
  */
