@@ -13,12 +13,13 @@
 #include <KComboBox>
 #include <KLineEdit>
 #include <KLocalizedString>
+#include <KMessageBox>
 
-#include <QVBoxLayout>
-#include <QLabel>
 #include <QCheckBox>
+#include <QLabel>
 #include <QPushButton>
 #include <QStackedWidget>
+#include <QVBoxLayout>
 
 using namespace ContactEditor;
 
@@ -40,7 +41,7 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
 
     mTypeCombo = new SelectAddressTypeComboBox(this);
     mTypeCombo->setObjectName(QStringLiteral("typeaddress"));
-    connect(mTypeCombo, QOverload<const QString &>::of(&SelectAddressTypeComboBox::activated), this, &AddressLocationWidget::slotChanged);
+    connect(mTypeCombo, &SelectAddressTypeComboBox::textHighlighted, this, &AddressLocationWidget::slotChanged);
     gridLayout->addWidget(mTypeCombo, 0, 0, 1, 2);
 
     QLabel *label = new QLabel(KContacts::Address::streetLabel(), this);
@@ -106,7 +107,7 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     mCountryCombo->setEditable(true);
     mCountryCombo->lineEdit()->setPlaceholderText(i18n("Add a Country"));
     mCountryCombo->setDuplicatesEnabled(false);
-    connect(mCountryCombo, QOverload<const QString &>::of(&KComboBox::activated), this, &AddressLocationWidget::slotChanged);
+    connect(mCountryCombo, &KComboBox::textHighlighted, this, &AddressLocationWidget::slotChanged);
     gridLayout->addWidget(mCountryCombo, 6, 1);
 
     mPreferredCheckBox = new QCheckBox(i18nc("street/postal", "This is the preferred address"), this);
@@ -132,6 +133,11 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     modifyButtonWidgetLayout->setContentsMargins(0, 0, 0, 0);
     mButtonStack->addWidget(modifyButtonWidget);
 
+    mRemoveAddress = new QPushButton(i18n("Remove Address"), this);
+    mRemoveAddress->setObjectName(QStringLiteral("removebuttonaddress"));
+    modifyButtonWidgetLayout->addWidget(mRemoveAddress);
+    connect(mRemoveAddress, &QPushButton::clicked, this, &AddressLocationWidget::slotRemoveAddress);
+
     mModifyAddress = new QPushButton(i18n("Update Address"), this);
     mModifyAddress->setObjectName(QStringLiteral("modifybuttonaddress"));
     modifyButtonWidgetLayout->addWidget(mModifyAddress);
@@ -223,10 +229,9 @@ void AddressLocationWidget::setAddress(const KContacts::Address &address)
     mLocalityEdit->setText(address.locality());
     mPostalCodeEdit->setText(address.postalCode());
     mPOBoxEdit->setText(address.postOfficeBox());
-    mPreferredCheckBox->setChecked(address.type() &KContacts::Address::Pref);
+    mPreferredCheckBox->setChecked(address.type() & KContacts::Address::Pref);
     if (address.isEmpty()) {
-        mCountryCombo->setItemText(mCountryCombo->currentIndex(),
-                                   QLocale::countryToString(QLocale().country()));
+        mCountryCombo->setItemText(mCountryCombo->currentIndex(), QLocale::countryToString(QLocale().country()));
     } else {
         mCountryCombo->setItemText(mCountryCombo->currentIndex(), mAddress.country());
     }
@@ -286,6 +291,17 @@ void AddressLocationWidget::slotUpdateAddress()
     }
 }
 
+void AddressLocationWidget::slotRemoveAddress()
+{
+    if (mCurrentMode == ModifyAddress) {
+        const auto result = KMessageBox::questionYesNo(this, i18n("Do you really want to delete this address?"));
+        if (result == KMessageBox::Yes) {
+            Q_EMIT removeAddress(mCurrentAddress);
+            reset();
+        }
+    }
+}
+
 void AddressLocationWidget::reset()
 {
     Q_EMIT updateAddressCanceled();
