@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,11 +12,13 @@
 #include <QWidget>
 class DateEditWidget;
 class KLineEdit;
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
 
-namespace ContactEditor {
+namespace ContactEditor
+{
 class PersonalEditorWidget : public QWidget
 {
     Q_OBJECT
@@ -26,6 +28,7 @@ public:
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact);
     void setReadOnly(bool readOnly);
+
 private:
     DateEditWidget *mBirthdateWidget = nullptr;
     DateEditWidget *mAnniversaryWidget = nullptr;
